@@ -12,83 +12,93 @@ import numba as nb
 from time import time
 
 
-def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
-               diagnostics=False, nsamples=None, sample_thresh=None,
+def bispectrum(*u, ntheta=None, kmin=None, kmax=None,
+               diagnostics=True, error=False,
+               nsamples=None, sample_thresh=None,
                compute_fft=True, exclude_upper=False, use_pyfftw=False,
                bench=False, progress=False, **kwargs):
     """
-    Estimate the mean bispectrum :math:`\\bar{B}(k_1, k_2, \\theta)`
-    and bicoherence index :math:`b(k_1, k_2, \\theta)` of a real
-    scalar or vector field :math:`U`.
+    Estimate the bispectrum :math:`B(k_1, k_2, \\cos\\theta)`
+    and bicoherence index :math:`b(k_1, k_2, \\cos\\theta)` of a real
+    scalar field :math:`u` or vector field :math:`\mathbf{u}`.
 
-    Assuming statistical homogeneity and isotropy, the bispectrum
-    :math:`B(\mathbf{k}_1, \mathbf{k}_2, \mathbf{k}_3)` is defined as the
+    Assuming statistical homogeneity, we define the bispectrum
+    :math:`B(\mathbf{k}_1, \mathbf{k}_2, \mathbf{k}_3)` as the
     3-point correlation function in Fourier space with
     :math:`\mathbf{k}_1 + \mathbf{k}_2 + \mathbf{k}_3 = 0`. For a
-    real :math:`U`
+    real :math:`u`
 
     .. math::
-        B(\mathbf{k}_1, \mathbf{k}_2, - \mathbf{k}_1 - \mathbf{k}_2) = 
-            \hat{U}(\mathbf{k}_1)\hat{U}(\mathbf{k}_2)
-            \hat{U}^{*}(\mathbf{k}_1+\mathbf{k}_2),
+        B(\mathbf{k}_1, \mathbf{k}_2, - \mathbf{k}_1 - \mathbf{k}_2) =
+            \\langle\\tilde{u}(\mathbf{k}_1)\\tilde{u}(\mathbf{k}_2)
+            \\tilde{u}^{*}(\mathbf{k}_1+\mathbf{k}_2)\\rangle,
 
-    where :math:`\hat{U}` is the Fourier transform of :math:`U`.
-    We define the mean bispectrum as
+    where :math:`\\tilde{u}` is the Fourier transform of :math:`u`
+    and :math:`\\langle\cdot\\rangle` is some choice of averaging.
+    For a vector field, the bispectrum is a 3-tensor
 
     .. math::
-        \\bar{B}(k_1, k_2, \\theta) = \\frac{1}{V_1 V_2} \int\int_{\Omega}
+        B_{ijk}(\mathbf{k}_1, \mathbf{k}_2, - \mathbf{k}_1 - \mathbf{k}_2) =
+            \\langle\\tilde{u}_i(\mathbf{k}_1)\\tilde{u}_j(\mathbf{k}_2)
+            \\tilde{u}_k^{*}(\mathbf{k}_1+\mathbf{k}_2)\\rangle,
+
+    where we have a bispectrum for each combination of vector
+    components.
+    Proceeding for the case of a scalar field, we compute our bispectrum
+    as
+
+    .. math::
+        B(k_1, k_2, \\cos\\theta) = \\frac{1}{V_1 V_2} \int\int_{\Omega}
             d^D \mathbf{k}_1 d^D \mathbf{k}_2 \ 
-                \hat{U}(\mathbf{k}_1)\hat{U}(\mathbf{k}_2)
-                    \hat{U}^{*}(\mathbf{k}_1 + \mathbf{k}_2),
+                \\tilde{u}(\mathbf{k}_1)\\tilde{u}(\mathbf{k}_2)
+                    \\tilde{u}^{*}(\mathbf{k}_1 + \mathbf{k}_2),
 
     and the bicoherence as
 
     .. math::
-        b(k_1, k_2, \\theta) = \\frac{
+        b(k_1, k_2, \\cos\\theta) = \\frac{
             |\int\int_{\Omega} d^D \mathbf{k}_1 d^D \mathbf{k}_2 \ 
-                \hat{U}(\mathbf{k}_1)\hat{U}(\mathbf{k}_2)
-                    \hat{U}^{*}(\mathbf{k}_1 + \mathbf{k}_2)|}{
+                \\tilde{u}(\mathbf{k}_1)\\tilde{u}(\mathbf{k}_2)
+                    \\tilde{u}^{*}(\mathbf{k}_1 + \mathbf{k}_2)|}{
             \int\int_{\Omega} d^D \mathbf{k}_1 d^D \mathbf{k}_2 \ 
-                |\hat{U}(\mathbf{k}_1)\hat{U}(\mathbf{k}_2)
-                    \hat{U}^{*}(\mathbf{k}_1 + \mathbf{k}_2)|}.
+                |\\tilde{u}(\mathbf{k}_1)\\tilde{u}(\mathbf{k}_2)
+                    \\tilde{u}^{*}(\mathbf{k}_1 + \mathbf{k}_2)|}.
 
-    :math:`\Omega` is the set of all unique
+    :math:`\Omega` is the set of
     (:math:`\mathbf{k}_1`, :math:`\mathbf{k}_2`) pairs such that
     :math:`|\mathbf{k}_1| \in [k_1, k_1+1)`,
     :math:`|\mathbf{k}_2| \in [k_2, k_2+1)`, and
-    :math:`\\arccos{(\hat{\mathbf{k}}_1 \cdot \hat{\mathbf{k}}_2)} \in [\\theta, \\theta+\\Delta \\theta)`.
-    By "unique" pairs, we mean (:math:`\mathbf{k}_1`, :math:`\mathbf{k}_2`)
-    but not the complex conjugate evaluations for
-    (:math:`-\mathbf{k}_1`, :math:`-\mathbf{k}_2`). Otherwise,
-    :math:`\\bar{B}` would be a real function.
+    :math:`\hat{\mathbf{k}}_1 \cdot \hat{\mathbf{k}}_2 \in [\\cos\\theta, \\cos\\theta+\\Delta \\cos\\theta)`.
+    We only consider :math:`(\mathbf{k}_2)_z > 0` to include
+    (:math:`\mathbf{k}_1`, :math:`\mathbf{k}_2`) contributions
+    but not their complex conjugates from
+    (:math:`-\mathbf{k}_1`, :math:`-\mathbf{k}_2`). The bispectrum defined
+    over :math:`\Omega` is real so this improves performance.
 
-    To calculate :math:`\\bar{B}`, we take the average
+    If the data is also statistically isotropic, then we can say that
+    :math:`B = B(k_1, k_2, \hat{\mathbf{k}}_1 \cdot \hat{\mathbf{k}}_2)`.
+
+    To calculate :math:`B`, we take the average
 
     .. math::
-        \\bar{B}(k_1, k_2, \\theta) = \\frac{1}{|\Omega|}
-            \sum\limits_{\Omega} \hat{U}(\mathbf{k}_1)\hat{U}(\mathbf{k}_2)
-                                 \hat{U}^{*}(\mathbf{k}_1 + \mathbf{k}_2),
+        B(k_1, k_2, \\cos\\theta) = \\frac{1}{|\Omega|}
+            \sum\limits_{\Omega} \\tilde{u}(\mathbf{k}_1)\\tilde{u}(\mathbf{k}_2)
+                                 \\tilde{u}^{*}(\mathbf{k}_1 + \mathbf{k}_2),
 
-    where now :math:`\hat{U}` is an FFT. For 3D fields, the full sum is often
+    where now :math:`\\tilde{u}` is an FFT. For 3D fields, the full sum is often
     too large to compute. Instead, we compute a naive Monte Carlo
-    integration over :math:`\Omega_N`, :math:`N` uniform samples from
-    the set :math:`\Omega`:
+    integration by drawing :math:`N` uniform samples
+    :math:`(\mathbf{k}_1^n, \mathbf{k}_2^n)` from the set :math:`\Omega`.
+    This defines an unbiased estimator of :math:`B`,
 
      .. math::
-        \\bar{B}_N(k_1, k_2, \\theta) = \\frac{1}{N}
-            \sum\limits_{\Omega_N} \hat{U}(\mathbf{k}_1)\hat{U}(\mathbf{k}_2)
-                                 \hat{U}^{*}(\mathbf{k}_1 + \mathbf{k}_2).
+        \\hat{B}(k_1, k_2, \\cos\\theta) = \\frac{1}{N}
+            \sum\limits_{n = 1}^{N} \\tilde{u}(\mathbf{k}_1^n)\\tilde{u}(\mathbf{k}_2^n)
+                                 \\tilde{u}^{*}(\mathbf{k}_1^n + \mathbf{k}_2^n).
 
     The same procedure is used to compute :math:`b`. By default, this
-    implementation returns :math:`\\bar{B}(k_1, k_2)`, the mean
-    bispectrum summed over triangle angle :math:`\\theta`.
-
-    To learn more, read `here <https://arxiv.org/pdf/astro-ph/0112551.pdf>`_.
-
-    .. note::
-        One can recover the sum over triangles by multiplying ``omega_N * B``
-        when ``nsamples = None``. Or, if ``ntheta = None``,
-        evaulate ``omega * B``.
+    implementation returns :math:`B(k_1, k_2)`, the
+    bispectrum summed over :math:`\\cos\\theta`.
 
     .. note::
         When considering the bispectrum as a function of triangle
@@ -100,24 +110,16 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
         Computing a boolean mask with ``np.isnan`` and reductions
         like ``np.nansum`` can be useful.
 
-    .. note::
-        Computing ``np.nansum(B*omega_N, axis=0)/np.sum(omega_N, axis=0)``
-        recovers the bispectrum summed over triangle angles.
-        To recover the corresponding bicoherence, evaulate
-        ``np.abs(np.nansum(B, axis=0)) / np.nansum(np.abs(B)/b, axis=0)``.
-
     Parameters
     ----------
-    U : `np.ndarray`
-        Scalar or vector field.
-        If vector data, pass arguments as ``U1, U2, ..., Un``,
-        where ``Ui`` is the ith vector component.
-        Each ``Ui`` can be 2D or 3D, and all must have the
-        same ``Ui.shape`` and ``Ui.dtype``. The vector
-        bispectrum will be computed as the sum over bispectra
-        of each component.
+    u : `np.ndarray`
+        Scalar field or vector components to correlate.
+        If vector data, pass arguments as ``u1, u2, u3``,
+        where ``ui`` is a vector component.
+        Each ``ui`` can be 2D or 3D, and all must have the
+        same ``ui.shape`` and ``ui.dtype``.
     ntheta : `int`, optional
-        Number of angular bins :math:`\\theta` between triangles
+        Number of angular bins :math:`\\cos\\theta` between triangles
         formed by wavevectors :math:`\mathbf{k_1}, \ \mathbf{k_2}`.
         If ``None``, sum over all triangle angles. Otherwise,
         return a bispectrum for each angular bin.
@@ -126,10 +128,15 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
         If ``None``, ``kmin = 1``.
     kmax : `int`, optional
         Maximum wavenumber in bispectrum calculation.
-        If ``None``, ``kmax = max(U.shape)//2``
+        If ``None``, ``kmax = max(u.shape)//2``
     diagnostics : `bool`, optional
-        Return the optional sampling and error diagnostics,
-        documented below.
+        Return the optional sampling and normalization diagnostics,
+        documented below. Set ``error = True`` to also return the
+        standard error of the mean.
+    error : `bool`, optional
+        Return standard error of the mean of the Monte-Carlo integration.
+        ``diagnostics = True`` must also be set. This will add a bit of
+        time to the calculation.
     nsamples : `int`, `float` or `np.ndarray`, shape `(kmax-kmin+1, kmax-kmin+1)`, optional
         Number of sample triangles or fraction of total
         possible triangles. This may be an array that
@@ -143,7 +150,8 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
     compute_fft : `bool`, optional
         If ``False``, do not take the FFT of the input data.
         FFTs should not be passed with the zero-frequency
-        component in the center.
+        component in the center, and it should have the same
+        shape as the real-space data.
     exclude_upper : `bool`, optional
         If ``True``, set points where :math:`k_1 + k_2 > k_{nyq}`
         to ``np.nan``. This keyword only applies when summing
@@ -162,27 +170,31 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
     Returns
     -------
     B : `np.ndarray`, shape `(m, kmax-kmin+1, kmax-kmin+1)`
-        Mean bispectrum :math:`\\bar{B}(k_1, k_2, \\theta)`.
+        Bispectrum :math:`B(k_1, k_2, \\cos\\theta)`.
     b : `np.ndarray`, shape `(m, kmax-kmin+1, kmax-kmin+1)`
-        Bicoherence index :math:`b(k_1, k_2, \\theta)`.
+        Bicoherence index :math:`b(k_1, k_2, \\cos\\theta)`.
     kn : `np.ndarray`, shape `(kmax-kmin+1,)`
         Left edges of wavenumber bins :math:`k_1` or :math:`k_2`
         along axis of bispectrum.
     theta : `np.ndarray`, shape `(m,)`, optional
-        Left edges of angular bins :math:`\\theta`, ranging from
-        :math:`[0, \ \\pi)`.
-    stderr : `np.ndarray`, shape `(m, kmax-kmin+1, kmax-kmin+1)`, optional
-        Standard error of the mean for each bin. This can be an
-        error estimate for the Monte Carlo integration.
-    omega_N : `np.ndarray`, shape `(m, kmax-kmin+1, kmax-kmin+1)`, optional
-        Number of evaluations in the bispectrum sum, :math:`|\\Omega_N|`.
+        Left edges of angular bins :math:`\\cos\\theta`, ranging from
+        :math:`[-1, \ 1)`.
+    counts : `np.ndarray`, shape `(m, kmax-kmin+1, kmax-kmin+1)`, optional
+        Number of evaluations in the bispectrum sum, :math:`N`.
     omega : `np.ndarray`, shape `(kmax-kmin+1, kmax-kmin+1)`, optional
         Number of possible triangles in the sample space, :math:`|\\Omega|`.
         This is implemented for if sampling were *not* restricted by the Nyquist
         frequency. Note that this is only implemented for ``ntheta = None``.
+    stderr : `np.ndarray`, shape `(m, kmax-kmin+1, kmax-kmin+1)`, optional
+        Standard error of the mean for each bin. This can be an
+        error estimate for the Monte Carlo integration. To convert
+        to the standard deviation, evaluate ``stderr * np.sqrt(counts)``.
     """
-    shape, ndim = nb.typed.List(U[0].shape), U[0].ndim
-    ncomp = len(U)
+    shape, ndim = nb.typed.List(u[0].shape), u[0].ndim
+    ncomp = len(u)
+
+    if ncomp not in [1, 3]:
+        raise ValueError("Pass either 1 scalar field or 3 vector components.")
 
     if ndim not in [2, 3]:
         raise ValueError("Data must be 2D or 3D.")
@@ -192,9 +204,8 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
     kmin = 1 if kmin is None else int(kmin)
     kn = np.arange(kmin, kmax+1, 1, dtype=int)
     dim = kn.size
-    theta = np.arange(0, np.pi, np.pi/ntheta) if ntheta is not None else None
-    # ...make costheta monotonically increase
-    costheta = np.flip(np.cos(theta)) if theta is not None else np.array([1.])
+    dtheta = 2/ntheta
+    costheta = np.arange(-1, 1, dtheta)+dtheta if theta is not None else np.array([1.])
 
     # theta = 0 should be included
     if theta is not None:
@@ -238,15 +249,16 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
     ffts = []
     for i in range(ncomp):
         if compute_fft:
-            temp = U[i]
+            temp = u[i]
             if use_pyfftw:
                 fft = _fftn(temp, **kwargs)
             else:
-                fft = np.fft.fftn(temp, **kwargs)
+                fft = np.fft.rfftn(temp, **kwargs)
             del temp
         else:
-            fft = U[i]
+            fft = u[i][..., :shape[-1]//2+1]
         ffts.append(fft)
+        del fft
 
     # Sampling settings
     if sample_thresh is None:
@@ -268,41 +280,43 @@ def bispectrum(*U, ntheta=None, kmin=None, kmax=None,
     compute_point = eval(f"_compute_point{ndim}D")
     args = (k1bins, k2bins, kn, costheta, kcoords,
             nsamples, sample_thresh, ndim, dim, shape,
-            progress, exclude_upper, diagnostics, compute_point, *ffts)
-    B, norm, omega, omega_N, stderr = _compute_bispectrum(*args)
+            progress, exclude_upper, error, compute_point, *ffts)
+    B, norm, omega, counts, stderr = _compute_bispectrum(*args)
 
     # Set zero values to nan values for division
-    mask = omega_N == 0.
+    mask = counts == 0.
     norm[mask] = np.nan
-    omega_N[mask] = np.nan
+    counts[mask] = np.nan
+
+    # Throw away imaginary part
+    B = B.real
 
     # Get bicoherence and average bispectrum
     b = np.abs(B) / norm
-    B.real /= omega_N
-    B.imag /= omega_N
+    B /= counts
 
-    # Convert omega_N to integer type
-    if diagnostics:
-        omega_N = omega_N.astype(np.int64)
-        omega_N[mask] = 0
+    # Prepare diagnostics
+    if error:
+        stderr[counts <= 1.] = np.nan
 
-    # Switch back to theta monotonically increasing
-    if ntheta is not None:
-        B[...] = np.flip(B, axis=0)
-        b[...] = np.flip(b, axis=0)
-        omega_N[...] = np.flip(omega_N, axis=0)
-        stderr[...] = np.flip(stderr, axis=0)
-    else:
-        B, b, omega_N, stderr = B[0], b[0], omega_N[0], stderr[0]
+    # If no theta bins, get rid of m dimension
+    if ntheta is None:
+        B, b = B[0], b[0]
+        if diagnostics:
+            counts = counts[0]
+            if error:
+                stderr = stderr[0]
 
     if bench:
         print(f"Time: {time() - t0:.04f} s")
 
     result = [B, b, kn]
     if ntheta is not None:
-        result.append(theta)
+        result.append(costheta-dtheta)
     if diagnostics:
-        result.extend([stderr, omega_N, omega])
+        result.extend([counts, omega])
+        if error:
+            result.append(stderr)
 
     return tuple(result)
 
@@ -354,19 +368,24 @@ def _fftn(image, overwrite_input=False, threads=-1, **kwargs):
 @nb.njit(parallel=True)
 def _compute_bispectrum(k1bins, k2bins, kn, costheta, kcoords, nsamples,
                         sample_thresh, ndim, dim, shape, progress,
-                        exclude, diagnostics, compute_point, *ffts):
+                        exclude, error, compute_point, *ffts):
     knyq = max(shape) // 2
     ntheta = costheta.size
+    nffts = len(ffts)
     bispec = np.full((ntheta, dim, dim), np.nan+1.j*np.nan, dtype=np.complex128)
     binorm = np.full((ntheta, dim, dim), np.nan, dtype=np.float64)
-    omega_N = np.full((ntheta, dim, dim), np.nan, dtype=np.float64)
+    counts = np.full((ntheta, dim, dim), np.nan, dtype=np.float64)
     omega = np.zeros((dim, dim), dtype=np.int64)
-    stderr = np.full((ntheta, dim, dim), np.nan, dtype=np.float64)
+    if error:
+        stderr = np.full((ntheta, dim, dim), np.nan, dtype=np.float64)
+    else:
+        stderr = np.zeros((1, 1, 1), dtype=np.float64)
     for i in range(dim):
         k1 = kn[i]
         k1ind = k1bins[i]
         nk1 = k1ind.size
-        for j in range(i+1):
+        dim2 = dim if nffts > 1 else i+1
+        for j in range(dim2):
             k2 = kn[j]
             if ntheta == 1 and (exclude and k1 + k2 > knyq):
                 continue
@@ -391,46 +410,58 @@ def _compute_bispectrum(k1bins, k2bins, kn, costheta, kcoords, nsamples,
                           bispecbuf, binormbuf, cthetabuf, countbuf,
                           *ffts)
             if ntheta == 1:
-                _fill_sum(i, j, bispec, binorm, omega_N, stderr,
-                          bispecbuf, binormbuf, countbuf, diagnostics)
+                _fill_sum(i, j, bispec, binorm, counts, stderr,
+                          bispecbuf, binormbuf, countbuf, nffts, error)
             else:
                 binned = np.searchsorted(costheta, cthetabuf)
                 _fill_binned_sum(i, j, ntheta, binned, bispec, binorm,
-                                 omega_N, stderr, bispecbuf, binormbuf,
-                                 countbuf, diagnostics)
-            omega[i, j], omega[j, i] = nk1*nk2, nk1*nk2
+                                 counts, stderr, bispecbuf, binormbuf,
+                                 countbuf, nffts, error)
+            omega[i, j] = nk1*nk2
+            if nffts == 1:
+                omega[j, i] = nk1*nk2
         if progress:
             with nb.objmode():
                 _printProgressBar(i, dim-1)
-    return bispec, binorm, omega, omega_N, stderr
+    return bispec, binorm, omega, counts, stderr
 
 
 @nb.njit(parallel=True, cache=True)
-def _fill_sum(i, j, bispec, binorm, omega_N, stderr,
-              bispecbuf, binormbuf, countbuf, diagnostics):
+def _fill_sum(i, j, bispec, binorm, counts, stderr,
+              bispecbuf, binormbuf, countbuf, nffts, error):
     N = countbuf.sum()
     norm = binormbuf.sum()
     value = bispecbuf.sum()
-    bispec[0, i, j], bispec[0, j, i] = value, value
-    binorm[0, i, j], binorm[0, j, i] = norm, norm
-    omega_N[0, i, j], omega_N[0, j, i] = N, N
-    if diagnostics and N > 1:
+    bispec[0, i, j] = value
+    binorm[0, i, j] = norm
+    counts[0, i, j] = N
+    if nffts == 1:
+        bispec[0, j, i] = value
+        binorm[0, j, i] = norm
+        counts[0, j, i] = N
+    if error and N > 1:
         variance = np.abs(bispecbuf - (value / N))**2
         err = np.sqrt(variance.sum() / (N*(N - 1)))
-        stderr[0, i, j], stderr[0, j, i] = err, err
+        stderr[0, i, j] = err
+        if nffts == 1:
+            stderr[0, j, i] = err
 
 
 @nb.njit(parallel=True, cache=True)
-def _fill_binned_sum(i, j, ntheta, binned, bispec, binorm, omega_N,
-                     stderr, bispecbuf, binormbuf, countbuf, diagnostics):
+def _fill_binned_sum(i, j, ntheta, binned, bispec, binorm, counts,
+                     stderr, bispecbuf, binormbuf, countbuf, nffts, error):
     N = np.bincount(binned, weights=countbuf, minlength=ntheta)
     norm = np.bincount(binned, weights=binormbuf, minlength=ntheta)
     value = np.bincount(binned, weights=bispecbuf.real, minlength=ntheta) +\
         1.j*np.bincount(binned, weights=bispecbuf.imag, minlength=ntheta)
-    bispec[:, i, j], bispec[:, j, i] = value, value
-    binorm[:, i, j], binorm[:, j, i] = norm, norm
-    omega_N[:, i, j], omega_N[:, j, i] = N, N
-    if diagnostics:
+    bispec[:, i, j] = value
+    binorm[:, i, j] = norm
+    counts[:, i, j] = N
+    if nffts == 1:
+        bispec[:, j, i] = value
+        binorm[:, j, i] = norm
+        counts[:, j, i] = N
+    if error:
         variance = np.zeros_like(countbuf)
         for n in range(ntheta):
             if N[n] > 1:
@@ -438,7 +469,9 @@ def _fill_binned_sum(i, j, ntheta, binned, bispec, binorm, omega_N,
                 mean = value[n] / N[n]
                 variance[idxs] = np.abs(bispecbuf[idxs] - mean)**2 / (N[n]*(N[n]-1))
         err = np.sqrt(np.bincount(binned, weights=variance, minlength=ntheta))
-        stderr[:, i, j], stderr[:, j, i] = err, err
+        stderr[:, i, j] = err
+        if nffts == 1:
+            stderr[:, j, i] = err
 
 
 @nb.njit(parallel=True, cache=True)
@@ -447,6 +480,8 @@ def _compute_point3D(k1ind, k2ind, kcoords, ntheta, nk1, nk2, shape,
                      cthetabuf, countbuf, *ffts):
     kx, ky, kz = kcoords[0], kcoords[1], kcoords[2]
     Nx, Ny, Nz = shape[0], shape[1], shape[2]
+    nffts = len(ffts)
+    fft1, fft2, fft3 = [ffts[0], ffts[0], ffts[0]] if nffts == 1 else ffts
     for idx in nb.prange(count):
         n, m = k1ind[samp[idx] % nk1], k2ind[samp[idx] // nk1]
         k1x, k1y, k1z = kx[n], ky[n], kz[n]
@@ -454,11 +489,14 @@ def _compute_point3D(k1ind, k2ind, kcoords, ntheta, nk1, nk2, shape,
         k3x, k3y, k3z = k1x+k2x, k1y+k2y, k1z+k2z
         if np.abs(k3x) > Nx//2 or np.abs(k3y) > Ny//2 or np.abs(k3z) > Nz//2:
             continue
-        sample, norm = 0, 0
-        for fft in ffts:
-            temp = fft[k1x, k1y, k1z]*fft[k2x, k2y, k2z]*np.conj(fft[k3x, k3y, k3z])
-            sample += temp
-            norm += np.abs(temp)
+        s1 = fft1[k1x, k1y, k1z] if k1z >= 0 \
+            else np.conj(fft1[-k1x, -k1y, -k1z])
+        s2 = fft2[k2x, k2y, k2z] if k2z >= 0 \
+            else np.conj(fft2[-k2x, -k2y, -k2z])
+        s3 = np.conj(fft3[k3x, k3y, k3z]) if k3z >= 0 \
+            else fft3[-k3x, -k3y, -k3z]
+        sample = s1*s2*s3
+        norm = np.abs(sample)
         bispecbuf[idx] = sample
         binormbuf[idx] = norm
         countbuf[idx] = 1
@@ -475,6 +513,8 @@ def _compute_point2D(k1ind, k2ind, kcoords, ntheta, nk1, nk2, shape,
                      cthetabuf, countbuf, *ffts):
     kx, ky = kcoords[0], kcoords[1]
     Nx, Ny = shape[0], shape[1]
+    nffts = len(ffts)
+    fft1, fft2, fft3 = [ffts[0], ffts[0], ffts[0]] if nffts == 1 else ffts
     for idx in nb.prange(count):
         n, m = k1ind[samp[idx] % nk1], k2ind[samp[idx] // nk1]
         k1x, k1y = kx[n], ky[n]
@@ -482,11 +522,11 @@ def _compute_point2D(k1ind, k2ind, kcoords, ntheta, nk1, nk2, shape,
         k3x, k3y = k1x+k2x, k1y+k2y
         if np.abs(k3x) > Nx//2 or np.abs(k3y) > Ny//2:
             continue
-        sample, norm = 0, 0
-        for fft in ffts:
-            temp = fft[k1x, k1y]*fft[k2x, k2y]*np.conj(fft[k3x, k3y])
-            sample += temp
-            norm += np.abs(temp)
+        s1 = fft1[k1x, k1y] if k1y >= 0 else np.conj(fft1[-k1x, -k1y])
+        s2 = fft2[k2x, k2y] if k2y >= 0 else np.conj(fft2[-k2x, -k2y])
+        s3 = np.conj(fft3[k3x, k3y]) if k3y >= 0 else fft3[-k3x, -k3y]
+        sample = s1*s2*s3
+        norm = np.abs(sample)
         bispecbuf[idx] = sample
         binormbuf[idx] = norm
         countbuf[idx] = 1
@@ -522,24 +562,24 @@ if __name__ == '__main__':
 
     N = 200
     np.random.seed(1234)
-    data = np.random.normal(size=N**2).reshape((N, N))+1
+    data = np.random.rand(N, N)+1
 
     kmin, kmax = 1, 100
-    result = bispectrum(data, nsamples=None, kmin=kmin, kmax=kmax,
-                        ntheta=2, progress=True, diagnostics=True, bench=True)
-    bispec, bicoh, kn, theta, stderr, omega_N, omega = result
+    result = bispectrum(data, nsamples=10000, kmin=kmin, kmax=kmax,
+                        ntheta=9, progress=True, bench=True)
+    bispec, bicoh, kn, theta, counts, omega = result
 
-    print(np.nansum(bispec))#, np.nansum(bicoh))
+    print(np.nansum(bispec), np.nansum(bicoh))
 
     tidx = 0
-    bispec, bicoh, omega_N, stderr = [x[tidx] for x in [bispec, bicoh, omega_N, stderr]]
+    bispec, bicoh, counts = [x[tidx] for x in [bispec, bicoh, counts]]
 
     # Plot
     cmap = 'plasma'
     labels = [r"$|B(k_1, k_2)|$", "$b(k_1, k_2)$",
-              "$arg \ B(k_1, k_2)$", "std error"]#, "counts"]
+              "$arg \ B(k_1, k_2)$", "counts"]#, "counts"]
     data = [np.log10(np.abs(bispec)), np.log10(bicoh),
-            np.angle(bispec), np.log10(stderr)]#, np.log10(omega_N)]
+            np.angle(bispec), np.log10(counts)]#, np.log10(counts)]
     fig, axes = plt.subplots(ncols=2, nrows=2)
     for i in range(len(data)):
         ax = axes.flat[i]
