@@ -9,41 +9,41 @@ import numpy as np
 from time import time
 
 
-def powerspectrum(*U, average=True, diagnostics=False,
+def powerspectrum(*u, average=True, diagnostics=False,
                   kmin=None, kmax=None, npts=None,
                   compute_fft=True, compute_sqr=True,
                   use_pyfftw=False, bench=False, **kwargs):
     """
-    Returns the 1D radially averaged power spectrum :math:`P(k)`
-    of a real scalar or vector field :math:`U`. Assuming statistical
-    homogeneity and isotropy, the power spectrum is the
+    Returns the isotropically averaged power spectrum :math:`P(k)`
+    of a real scalar or vector field :math:`u`. Assuming statistical
+    homogeneity, the power spectrum is the
     2-point correlation function in Fourier space with
-    :math:`\mathbf{k} + \mathbf{k}' = 0`. We define the radially
+    :math:`\mathbf{k} + \mathbf{k}' = 0`. We define this isotropically
     averaged power spectrum as
 
     .. math::
         P(k) = \int\limits_{|\mathbf{k}| \in [k, \ k+\Delta k)} 
-                   d^D \mathbf{k} \ |\hat{U}(\mathbf{k})|^2,
+                   d^D \mathbf{k} \ |\\tilde{u}(\mathbf{k})|^2,
 
-    where :math:`\hat{U}` is the FFT of :math:`U`.
+    where :math:`\\tilde{u}` is the FFT of :math:`u`.
 
     We approximate this integral as
 
     .. math::
         P(k) = \\frac{V_k}{N_k} \sum\limits_{|\mathbf{k}| \in [k, k+\Delta k)}
-                   |\hat{U}(\mathbf{k})|^2,
+                   |\\tilde{u}(\mathbf{k})|^2,
 
     where :math:`V_k` and :math:`N_k` are the volume and number of points
     in the :math:`k^{th}` bin.
 
     Parameters
     ----------
-    U : `np.ndarray`
+    u : `np.ndarray`
         Scalar or vector field.
-        If passing vector data, pass arguments as ``U1, U2, ..., Un``
-        where ``Ui`` is the ith vector component.
-        Each ``Ui`` can be 1D, 2D, or 3D, and all must have the
-        same ``Ui.shape`` and ``Ui.dtype``.
+        If passing vector data, pass arguments as ``u1, u2, ..., un``
+        where ``ui`` is the ith vector component.
+        Each ``ui`` can be 1D, 2D, or 3D, and all must have the
+        same ``ui.shape`` and ``ui.dtype``.
     average : `bool`, optional
         If ``True``, average over values in a given
         bin and multiply by the bin volume.
@@ -56,7 +56,7 @@ def powerspectrum(*U, average=True, diagnostics=False,
         If ``None``, ``kmin = 1``.
     kmax : `int` or `float`, optional
         Maximum wavenumber in power spectrum bins.
-        If ``None``, ``kmax = max(U.shape)//2``.
+        If ``None``, ``kmax = max(u.shape)//2``.
     npts : `int`, optional
         Number of modes between ``kmin`` and ``kmax``,
         inclusive.
@@ -86,22 +86,22 @@ def powerspectrum(*U, average=True, diagnostics=False,
         Radially averaged power spectrum :math:`P(k)`.
     kn : `np.ndarray`, shape `(npts,)`
         Left edges of radial bins :math:`k`.
-    stderr : `np.ndarray`, shape `(npts,)`, optional
-        Standard error of the mean multiplied with :math:`V_k`
-        in each bin.
-    vol : `np.ndarray`, shape `(npts,)`, optional
-        Volume :math:`V_k` of each bin.
     counts : `np.ndarray`, shape `(npts,)`, optional
         Number of points :math:`N_k` in each bin.
+    vol : `np.ndarray`, shape `(npts,)`, optional
+        Volume :math:`V_k` of each bin.
+    stdev : `np.ndarray`, shape `(npts,)`, optional
+        Standard deviation multiplied with :math:`V_k`
+        in each bin.
     """
     if bench:
         t0 = time()
 
-    ndim = U[0].ndim
-    ncomp = len(U)
-    N = max(U[0].shape)
+    ndim = u[0].ndim
+    ncomp = len(u)
+    N = max(u[0].shape)
 
-    real = True if np.issubdtype(U[0].dtype, np.floating) else False
+    real = True if np.issubdtype(u[0].dtype, np.floating) else False
 
     if ndim not in [1, 2, 3]:
         raise ValueError("Dimension of image must be 1, 2, or 3.")
@@ -109,7 +109,7 @@ def powerspectrum(*U, average=True, diagnostics=False,
     # Compute FFT
     density = None
     for i in range(ncomp):
-        comp = U[i]
+        comp = u[i]
         if compute_fft:
             # Compute fft of a component
             if use_pyfftw:
@@ -162,7 +162,7 @@ def powerspectrum(*U, average=True, diagnostics=False,
     elif ndim == 3:
         fac = 4./3.*np.pi
     spectrum = np.zeros_like(kn)
-    stderr = np.zeros_like(kn)
+    stdev = np.zeros_like(kn)
     vol = np.zeros_like(kn)
     counts = np.zeros(kn.shape, dtype=np.int64)
     for i, ki in enumerate(kn):
@@ -175,7 +175,7 @@ def powerspectrum(*U, average=True, diagnostics=False,
             spectrum[i] = np.sum(samples)
         if diagnostics:
             Nk = samples.size
-            stderr[i] = vk * (np.std(samples, ddof=1) / np.sqrt(Nk))
+            stdev[i] = vk * np.std(samples, ddof=1)
             vol[i] = vk
             counts[i] = Nk
 
@@ -186,7 +186,7 @@ def powerspectrum(*U, average=True, diagnostics=False,
 
     result = [spectrum, kn]
     if diagnostics:
-        result.extend([stderr, vol, counts])
+        result.extend([counts, vol, stdev])
 
     return tuple(result)
 
@@ -261,7 +261,7 @@ if __name__ == '__main__':
     fc.gen_cube()
     data = fc.cube
 
-    psd, kn, stderr, vol, N = powerspectrum(data, diagnostics=True)
+    psd, kn, stdev, vol, N = powerspectrum(data, diagnostics=True)
 
     print(psd.mean())
 
